#[example_attribute]Expand description
An attribute macro example
This macro demonstrates how to create an attribute macro in this crate.
#[example_attribute]An attribute macro example
This macro demonstrates how to create an attribute macro in this crate.