RubyClass

Derive Macro RubyClass 

#[derive(RubyClass)]
A derive macro for defining Ruby classes

This macro generates code that defines a Ruby class with the same name as the struct, handles struct fields appropriately, and integrates with the existing Ruby API.